@@ -7,6 +7,18 @@ from discord.http import Route
 from discord.utils import DISCORD_EPOCH
 
 
+__all__ = (
+    'ResponseType',
+    'InteractionDataOption',
+    'InteractionData',
+    'Interaction',
+    'Type',
+    'OptionChoice',
+    'Option',
+    'SlashCommand'
+)
+
+
 #-----------------------------------+
 #       Interaction wrappers        |
 #-----------------------------------+
@@ -280,6 +292,7 @@ class Interaction:
             state=state
         )
         self.editable = False
+        self.__expired = False
     @property
     def channel(self):
         if self._channel is None:
@@ -294,6 +307,11 @@ class Interaction:
     @property
     def created_at(self):
         return datetime.datetime.fromtimestamp(((self.id >> 22) + DISCORD_EPOCH) / 1000)
+    @property
+    def expired(self):
+        if self.__expired: return True
+        self.__expired = datetime.datetime.utcnow() - self.created_at > datetime.timedelta(minutes=15)
+        return self.__expired
 
     def get(self, name: str, default=None):
         """Equivalent to :class:`InteractionData.get`"""
@@ -308,6 +326,7 @@ class Interaction:
         return self.data.option_at(index)
 
     async def reply(self, content=None, *,  embed=None, embeds=None,
+                                            file=None, files=None,
                                             tts=False, hide_user_input=False,
                                             ephemeral=False, delete_after=None,
                                             allowed_mentions=None, type=None):
@@ -335,6 +354,11 @@ class Interaction:
         type : :class:`int` | :class:`ResponseType`
             sets the response type. If it's not specified, this method sets
             it according to ``hide_user_input``, ``content`` and ``embed`` params.
+        file : :class:`discord.File`
+            if it's the first interaction reply, the file will be ignored due to API limitations.
+            Everything else is the same as in :class:`discord.TextChannel.send()` method.
+        files : List[:class:`discord.File`]
+            same as ``file`` but for multiple files.
 
         Raises
         ------
@@ -348,6 +372,15 @@ class Interaction:
         message : :class:`discord.Message` | ``None``
             The response message that has been sent or ``None`` if the message is ephemeral
         '''
+        # If expired, use TextChannel.send instead
+        if self.expired:
+            return await self.channel.send(
+                content=content, embed=embed,
+                file=file, files=files,
+                tts=tts, delete_after=delete_after,
+                allowed_mentions=allowed_mentions
+            )
+        # Otherwise perform interacting
         is_empty_message = content is None and embed is None
         # Which callback type is it
         if type is None:
@@ -407,6 +440,7 @@ class Interaction:
             ),
             json=_json
         )
+        self.__expired = True
         # Ephemeral messages aren't stored and can't be deleted or edited
         # Same for empty type-1 & type-5 messages
         if ephemeral or is_empty_message:
