@@ -58,8 +58,7 @@ class SlashCommandResponse:
             self.registerable = None
         self._auto_merged = False
         # Cog indication
-        self.__cog_checked = False
-        self._cog_name = None
+        self._cog_name = class_name(func)
         self.__cog = None
     
     async def __call__(self, interaction):
@@ -81,14 +80,8 @@ class SlashCommandResponse:
             if retry_after:
                 raise CommandOnCooldown(bucket, retry_after)
 
-    def _inject_cog(self, name):
-        if self.__cog_checked:
-            return
-        self.__cog_checked = True
-        cog = get_class(self.func)
-        if cog is not None:
-            self._cog_name = name
-            self.__cog = cog(self.client)
+    def _inject_cog(self, cog):
+        self.__cog = cog
 
     async def _run_checks(self, ctx):
         for _check in self.checks:
@@ -563,20 +556,20 @@ class SlashClient:
         self.is_ready = False
         self.client.add_listener(self._on_shard_connect, 'on_shard_connect')
         self.client.add_listener(self._on_connect, 'on_connect')
-        # Link the slash ext to client
-        self.client.slash = self
-        # Tracking loading of cogs
+        # Modify cog loader
         _add_cog = self.client.add_cog
-        def add_cog_2(name):
-            self._inject_cogs(name)
-            _add_cog(name)
+        def add_cog_2(cog):
+            self._inject_cogs(cog)
+            _add_cog(cog)
         self.client.add_cog = add_cog_2
-        # Tracking unloading of cogs
+        # Modify cog unloader
         _rem_cog = self.client.remove_cog
         def rem_cog_2(name):
             self._eject_cogs(name)
             _rem_cog(name)
         self.client.remove_cog = rem_cog_2
+        # Link the slash ext to client
+        self.client.slash = self
 
     @property
     def commands(self):
@@ -1036,9 +1029,10 @@ class SlashClient:
             await self.delete_guild_command(guild_id, cmd.id)
 
     # Internal things
-    def _inject_cogs(self, name):
+    def _inject_cogs(self, cog):
         for cmd in self.commands.values():
-            cmd._inject_cog(name)
+            if cmd._cog_name == cog.__cog_name__:
+                cmd._inject_cog(cog)
         if self.is_ready:
             self.client.loop.create_task(self._auto_register_or_patch())
     
